% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Peter_CoRpower_trinary.R
\name{computepower}
\alias{computepower}
\alias{computepower.n}
\title{Sample size/power calculations for assessing biomarkers as correlates of risk (CoRs) accounting for measurement
error and treatment efficacy}
\usage{
computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2,
  noobsatriskmotaucontrolsALL, risk0, RRoverall, Plat0, Plat2, P0 = 0.3,
  P2 = 0.2, RRlat0 = seq(1, RRoverall, len = 20), RRlat1 = rep(RRoverall,
  20), PlatVElowest, VElowestvect, controlcaseratio = 5, M = 100,
  alpha = 0.05, sigma2obs = 1, rhos = c(1, 0.9, 0.7, 0.5), Spec = rep(1,
  4), FP1 = rep(0, 4), Sens = rep(1, 4), FN1 = rep(0, 4))

computepower.n(noobsatriskmotaucasesvectALL, noobsatriskmotaucasesvectPhase2,
  noobsatriskmotaucontrolsvectALL, risk0, RRoverall, Plat0, P2, P0, RRlat2point,
  RRlat1point, RRlat0point, PlatVElowest, VElowest, controlcaseratio = 5,
  M = 100, alpha = 0.05, sigma2obs = 1, rhos = c(1, 0.9, 0.7, 0.5),
  Spec = rep(1, 4), FP1 = rep(0, 4), Sens = rep(1, 4), FN1 = rep(0, 4))
}
\arguments{
\item{noobsatriskmotaucasesALL}{Number of subjects in the vaccine group at-risk at tau and with the clinical event (cases) by taumax (regardless of whether the biomarker is measured).}

\item{noobsatriskmotaucasesPhase2}{Number of subjects in the vaccine group at-risk at tau and with the clinical event (cases) by taumax and with the biomarker measured (i.e., in Phase 2).}

\item{noobsatriskmotaucontrolsALL}{Number of subjects in the vaccine group at-risk at tau and without the clinical event (controls) by taumax (regardless of whether the biomarker is measured).}

\item{risk0}{Estimated probability that a placebo recipient at-risk at tau experiences the clinical event by taumax.}

\item{RRoverall}{One minus the overall vaccine efficacy (VE).}

\item{Plat0}{For a trichotomous biomarker (or binary as a special case), probability that the (latent) true biomarker takes the lowest (low) value.}

\item{Plat2}{For a trichotomous biomarker (or binary as a special case), probability that the (latent) true biomarker takes the highest (high) value.}

\item{P0}{For a trichotomous biomarker (or binary as a special case), probability that the measured/observed biomarker takes the lowest (low) value.  If unspecified, this parameter is set to \code{Plat0}.}

\item{P2}{For a trichotomous biomarker (or binary as a special case), probability that the measured/observed biomarker takes the highest (high) value.  If unspecified, this parameter is set to \code{Plat2}.}

\item{RRlat0}{For a trichotomous biomarker (or binary as a special case), a vector of values corresponding to one minus VE for the lowest (low) true biomarker subgroup.  Each value of \code{RRlat0} corresponds to one unique effect size (RR_t).}

\item{RRlat1}{For a trichotomous biomarker, a vector of values corresponding to one minus VE for the middle true biomarker subgroup.  For a binary biomarker, \code{RRlat1} can be left unspecified.}

\item{PlatVElowest}{For a continuous biomarker, the percentage of vaccine recipients with the lowest value of VE.}

\item{VElowestvect}{For a continuous bioarker, a vector of values corresponding to the lowest possible value of VE.  Typical applications will range \code{VElowestvect} from 0 to 1 - \code{RRoverall}.}

\item{controlcaseratio}{Number of controls sampled per case in the vaccine arm (i.e. sampled in to Phase 2).}

\item{M}{Number of simulated clinical trials.}

\item{alpha}{Two-sided type-I error rate for CoR hypothesis tests.}

\item{sigma2obs}{For a continuous biomarker, or for a trichotomous or binary biomarker simulated using `approach 2', the variance of the continuous measured/observed biomarker.}

\item{rhos}{For a continuous biomarker, or for a trichotomous or binary biomarker simulated using 'approach 2', a vector of length 4 with values for the fraction of protection-relevant variability in the measured/observed continuous biomarker.  The first element of this vector should be 1, corresponding to the case of no measurement error.}

\item{Spec}{For a trichotomous biomarker (or binary as a special case), simulated using 'approach 1', a vector of length 4 with values for the sensitivity of the measured biomarker. Specifying \code{Spec = rep(1,4)}, \code{FP1 = rep(0,4)}, \code{Sens = rep(1,4)}, and \code{FN1 = rep(0,4)} indicates that approach 2 is used.}

\item{FP1}{For a trichotomous biomarker (or binary as a special case), simulated using 'approach 1', a vector of length 4 with values for the first false positive rate (FP^1) of the measured/observed biomarker. Specifying \code{Spec = rep(1,4)}, \code{FP1 = rep(0,4)}, \code{Sens = rep(1,4)}, and \code{FN1 = rep(0,4)}  indicates that approach 2 is used.}

\item{Sens}{For a trichotomous biomarker (or binary as a special case), simulated using 'approach 1', a vector of length 4 with values for the specificity of the measured/observed biomarker. Specifying \code{Spec = rep(1,4)}, \code{FP1 = rep(0,4)}, \code{Sens = rep(1,4)}, and \code{FN1 = rep(0,4)}  indicates that approach 2 is used.}

\item{FN1}{For a trichotomous biomarker (or binary as a special case), simulated using 'approach 1', a vector of length 4 with values for the first false negative rate (FN^1) of the measured/observed biomarker. Specifying \code{Spec = rep(1,4)}, \code{FP1 = rep(0,4)}, \code{Sens = rep(1,4)}, and \code{FN1 = rep(0,4)}  indicates that approach 2 is used.}

\item{noobsatriskmotaucasesvectALL}{Vector of the number of cases in the vaccine group at-risk at tau and a case by taumax (regardless of whether the biomarker is measured).}

\item{noobsatriskmotaucasesvectPhase2}{Vector of the number of cases in the vaccine group at-risk at tau and a case by taumax and with the biomarker measured (i.e., in Phase 2).}

\item{noobsatriskmotaucontrolsvectALL}{Vector of the number of controls in the vaccine group at-risk at tau and not diseased at the end of follow-up taumax (regardless of whether the biomarker is measured).}

\item{RRlat2point}{For a trichotomous biomarker, one minus VE for the latent high biomarker subgroup.}

\item{RRlat1point}{For a trichotomous biomarker, one minus VE for the latent middle biomarker subgroup.}

\item{RRlat0point}{For a trichotomous biomarker, one minus VE for the latent low biomarker subgroup.}

\item{VElowest}{The lowest possible value of vaccine efficacy}
}
\value{
Power- the fraction of simulated trials in which the null hypothesis H_0 (expression (14) of the manuscript for a trichotomous (or binary) biomarker and expression (16) for a continuous biomarker) is rejected.
}
\description{
Performs sample size/power calculations for assessing biomarkers as correlates of risk (CoRs) accounting for measurement error and treatment efficacy [Gilbert, Janes, and Huang (2015).
``Power/Sample Size Calculations for Assessing Correlates of Risk in Clinical Efficacy Trials.'']
}
\details{
This function performs simulations to calculate the power for testing whether a trichotomous or continuous biomarker
is a correlate of risk (CoR).

This program considers the scenario \code{RRlat1 = RRoverall}, which yields the formula
\code{1-RRoverall = (Plat0*VElat0 + Plat2*VElat2)/(Plat0 + Plat2)}.
For fixed values of \code{Plat0} and \code{Plat2}, this links \code{1-RRlat0} to \code{1-RRlat2} by the
formula \code{1-RRlat2 = (1-RRoverall*(Plat0+Plat2) - Plat0*(1-RRlat0))/Plat2}, which
is what the function uses to obtain \code{RRlat2}.

Following Step 7 in the manuscript, the measurement error in a trichotomous (or binary) biomarker is accounted for in one of two ways.
Approach 1 specifies \code{Spec}, \code{Sens}, \code{FP1}, and \code{FN1} which determine
\code{FP2} and \code{FN2} from equations (7) and (8).  Four values are required for each input parameter, to allow the evaluation of biomarkers with different levels of measurement error.

Approach 2 for a trichotomous (or binary) biomarker specifies \code{sigma2obs} and \code{rho}, again requiring four settings
for \code{rho}; this approach assumes the normal measurement error model (4) in the manuscript.  Specifying \code{Spec = rep(1,4)}, \code{FP1 = rep(0,4)}, \code{Sens = rep(1,4)}, and \code{FN1 = rep(0,4)}
defaults to approach 2, which is what is used in illustrations in the manuscript.

For a continuous biomarker, \code{VElowestvect}, \code{sigma2obs} and \code{rho} must be specified.  Setting \code{VElowestvect = NULL}
indicates that the biomarker is not continuous (it is trichotomous).

This program implements a scenario with without-replacement-sampling (e.g., typically used in case-control and 2-phase sampling)
}
\section{Functions}{
\itemize{
\item \code{computepower.n}: Vectors are inputted to repeat power calculations at multiple sample sizes.
}}
\examples{
## 'Global' parameters (independent of marker)
VEoverall <- 0.26   # VE in the at-risk-month-tau cohort
RRoverall <- 1 - VEoverall
noobsatriskmotaucasesALL <- 41
noobsatriskmotaucontrolsALL <- 7662
noobsatriskmotaucasesPhase2 <- 41
risk1 <- noobsatriskmotaucasesALL/(noobsatriskmotaucasesALL + noobsatriskmotaucontrolsALL)
risk0 <- risk1/RRoverall # risk in placebo

## Parameters used for the trichotomous or binary biomarker calculations, Approach 1
## For no measurement error scenario, set
## Spec[1]=1, FP1[1]=0, Sens[1]=1, FN1[1]=0
## Note the other elements of at least one of these four parameter vectors need
## to be set to a different value to tell the program to use Approach 1
Spec <- c(1, 0.9, 0.8, 0.7)
FP1 <- rep(0,4)
Sens <- c(1, 0.9, 0.8, 0.7)
FN1 <- rep(0,4)
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve

## Parameters used for continuous biomarker calculations, or
## for trichotomous/binary biomarkers under Approach 2
## Note these values are needed but are immaterial trichotomous/binary Approach 1
sigma2obs <- 1
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case
PlatVElowest <- 0.40
VElowestvect <- seq (0, 1-RRoverall,len=100)

#################################################
## use the function to perform power calculations
#################################################

## Binary biomarker, Approach 1 ##
Spec <- c(1, 0.9, 0.8, 0.7)
FP1 <- rep(0,4)
Sens <- c(1, 0.9, 0.8, 0.7)
FN1 <- rep(0,4)
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve

## i.e. Plat1=P1=0 and Plat0 = 1- Plat2
Plat0 <- 0.1
Plat2 <- 1-Plat0
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set
## Note these values are needed but are immaterial for trichotomous/binary markers
sigma2obs <- 1 #
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case

M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest=0,VElowestvect=NULL,
controlcaseratio, M, alpha=0.05, sigma2obs, rhos, Spec, FP1, Sens, FN1)


## Trichotomous biomarker, Approach 1 ##
Spec <- c(1, 0.9, 0.8, 0.7)
FP1 <- rep(0,4)
Sens <- c(1, 0.9, 0.8, 0.7)
FN1 <- rep(0,4)
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve

Plat0 <- 0.1
Plat2 <- 0.4
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set
## Note these values are needed but are immaterial for trichotomous/binary markers
sigma2obs <- 1 #
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case

M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest=0,
VElowestvect=NULL, controlcaseratio, M, alpha=0.05, sigma2obs, rhos, Spec, FP1, Sens, FN1)


## Binary biomarker, Approach 2 ##
Spec <- Sens <- rep(1,4)
FP1 <- FN1 <- rep(0,4)

RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve

Plat0 <- 0.1
Plat2 <- 1-Plat0
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set
## Note these values are needed but are immaterial for trichotomous/binary markers
sigma2obs <- 1 #
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case

M <- 1000
controlcaseratio <- 5
## Note these values are needed but are immaterial for trichotomous/binary markers
sigma2obs <- 1 #
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case

ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL, risk0,
RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest=0,VElowestvect=NULL, controlcaseratio,
M, alpha=0.05, sigma2obs, rhos, Spec, FP1, Sens, FN1)


## Trichotomous biomarker, Approach 2 ##
Spec <- Sens <- rep(1,4)
FP1 <- FN1 <- rep(0,4)

RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve
Plat0 <- 0.1
Plat2 <- 0.4
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set
## Note these values are needed but are immaterial for trichotomous/binary markers
sigma2obs <- 1 #
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case

M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest=0,VElowestvect=NULL,
controlcaseratio, M, alpha=0.05, sigma2obs, rhos, Spec, FP1, Sens, FN1)


## Continuous biomarker ##
sigma2obs <- 1
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case
PlatVElowest <- 0.40
VElowestvect <- seq (0, 1-RRoverall,len=100)

##Note these values are needed but are immaterial for continous markers
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve
Plat0 <- 0.1
Plat2 <- 0.4
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set

M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest,VElowestvect,
controlcaseratio, M, alpha=0.05, sigma2obs, rhos)

#######################
## plotting the results
#######################

## trichotomous biomarker Approach 1
Spec <- c(1, 0.9, 0.8, 0.7)
FP1 <- rep(0,4)
Sens <- c(1, 0.9, 0.8, 0.7)
FN1 <- rep(0,4)
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve
sigma2obs <- 1
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case
Plat0 <- 0.1
Plat2 <- 0.4
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set
M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest=0,
VElowestvect=NULL, controlcaseratio, M, alpha=0.05, sigma2obs=NULL, rhos=NULL, Spec, FP1, Sens, FN1)
## plot power vs. CoR risk ratio in vaccine group (hi vs. lo)
## file name = paste("powerstrinary",P2,P1,controlcaseratio,".dat")
powstrin40105 <- matrix(scan('powerstrinary0.40.15.dat'),ncol=4,byrow=T)
VEoverall <- scan('VEoverallCoRpower.dat')
alpha <- scan('alpha.dat')
rhos <- scan('rhos.dat')
RRlat2 <- scan('RRlat2.dat')
RRlat0 <- scan('RRlat0.dat')
nnALL <- scan('sampsizeALL.dat')
nPhase2 <- scan('numbeventsPhase2.dat')
corrr <- RRlat2/RRlat0

postscript("powertrichotomous_CoR.eps",horizontal=T)
par(cex.axis=1.2,cex.lab=1.2,cex.main=1.2,mar=c(5.1,4.6,3.1,1.1),oma=c(5,3,5,5),las=1)
xlims <- c(min(corrr),1)
plot(corrr,powstrin40105[,1],xlim=xlims,ylim=c(0,1),type='n',xlab="CoR Risk Ratio RR_t(rho=1) in Vaccine Group (Hi vs. Lo)",ylab="Power")
title("P0 = Plat0 = 0.1; P2 = Plat2 = 0.4")

axis(1)
axis(2)
lines(corrr,powstrin40105[,1],lty=1,col="blue",lwd=4)
lines(corrr,powstrin40105[,2],lty=2,col="orange",lwd=4)
lines(corrr,powstrin40105[,3],lty=3,col="green",lwd=4)
lines(corrr,powstrin40105[,4],lty=4,col="black",lwd=4)

legend(x="topright",legend=c(paste("Power rho=",rhos[1],sep=""),paste("Power rho=",rhos[2],sep=""),paste("Power rho=",rhos[3],sep=""),paste("Power rho=",rhos[4],sep="")),
lty=c(1,2,3,4),col=c("blue","orange","green","black"),lwd=2)
mtext(paste("Power to Detect a Trichotomous CoR in Vaccine Recipients [2-sided alpha = ",alpha,"]"),outer=T,cex=1.3)
mtext(paste("Overall VE = ",VEoverall,"; Number controls  = ",round(controlcaseratio*nPhase2),"; Number cases = ",round(nPhase2),"; Controls:cases = ",
controlcaseratio,":1"),side=1,line=0.7,outer=T,cex=1.3)
mtext(paste("VElat_0 varies from ",VEoverall," to 0 as VElat_2 varies from ",VEoverall," to ",round(2*VEoverall,2)),side=1,line=3,outer=T,cex=1.3)
## Note: the upper limit is VEoverall*(PlatloVE+PlathiVE)/PlathiVE, in the special case of this plot with
## PlatloVE = PlathiVE, this simplifies to 2*VE_0.
dev.off()

## continuous biomarker
sigma2obs <- 1
rhos <- c(1,0.9,0.7,0.5) # rho = 1 corresponds to no measurement error case
PlatVElowest <- 0.40
VElowestvect <- seq (0, 1-RRoverall,len=100)
##Note these values are needed but are immaterial for continous markers
RRlat1 <- rep(0,100) # will be turned into NA in computepower() for binary case
RRlat0 <- seq(1,RRoverall,len=100) # 100 data points for the power curve
Plat0 <- 0.1
Plat2 <- 0.4
P2 <- Plat2 # different values of P2 can be set
P0 <- Plat0 # different values of P0 can be set

M <- 1000
controlcaseratio <- 5
ans <- computepower(noobsatriskmotaucasesALL, noobsatriskmotaucasesPhase2, noobsatriskmotaucontrolsALL,
risk0, RRoverall, Plat0,Plat2, P0,P2, RRlat0,RRlat1, PlatVElowest,VElowestvect,
controlcaseratio, M, alpha=0.05, sigma2obs, rhos)
## Plot Power vs. CoR Relative Risk per SD Increase in X*
## Power to Detect a Normally Distributed CoR in Vaccine Recipients [ 2-sided alpha  0.05]
VEoverall <- scan('VEoverallCoRpower.dat')
alpha <- scan('alpha.dat')
rhos <- scan('rhos.dat')
RRlat2 <- scan('RRlat2.dat')
RRlat0 <- scan('RRlat0.dat')
nnALL <- scan('sampsizeALL.dat')
nPhase2 <- scan('numbeventsPhase2.dat')
PlatVElowest <- scan('PlatVElowest.dat')
RRs <- scan('RRs.dat')
reverseRRs <- RRs[length(RRs):1]
## The 5 refers to a controlcaseratio of 5:1
powscont5 <- matrix(scan('powerscont5.dat'),ncol=4,byrow=T)
reversepowscont <- powscont5[nrow(powscont5):1,]

sigma2tr <- 1
sigma2erho1 <- ((1-rhos[1])/rhos[1])*sigma2tr
sigma2erho2 <- ((1-rhos[2])/rhos[2])*sigma2tr
sigma2erho3 <- ((1-rhos[3])/rhos[3])*sigma2tr
sigma2erho4 <- ((1-rhos[4])/rhos[4])*sigma2tr
benchmarklab="V2"
benchmarkestRRrho1 <- 0.57 # From Haynes et al. 2012
benchmarkestRRrho2 <- benchmarkestRRrho1^(1/sqrt(rhos[2]))
benchmarkestRRrho3 <- benchmarkestRRrho1^(1/sqrt(rhos[3]))
benchmarkestRRrho4 <- benchmarkestRRrho1^(1/sqrt(rhos[4]))

postscript("powercontinuous_CoR.eps",horizontal=T)
par(cex.axis=1.2,cex.lab=1.2,cex.main=1.2,las=1,oma=c(3,3,4,4))
plot(RRs,powscont5[,1],ylim=c(0,1),type='n',xlab="Vaccine Group CoR Relative Risk RR_c per 1 SD Increase in the True Biomarker X*",ylab="Power",axes=FALSE)
box()

m <-length(RRs)
RRsgrid <- seq(RRs[1],RRs[m],len=10)
axis(1,at=RRsgrid,labels=round(RRsgrid,2))
axis(2,at=c(0,.1,.2,.3,.4,.5,.6,.7,.8,.9,1.0),labels=c(0,.1,.2,.3,.4,.5,.6,.7,.8,.9,1.0))

lines(RRs,powscont5[,1],lty=1,col="blue",lwd=4)
lines(RRs,powscont5[,2],lty=2,col="orange",lwd=4)
lines(RRs,powscont5[,3],lty=3,col="green",lwd=4)
lines(RRs,powscont5[,4],lty=4,col="black",lwd=4)

ind <- c(1:m)[(RRs - benchmarkestRRrho1) <= 0 & (RRs - benchmarkestRRrho1)==max((RRs - benchmarkestRRrho1)[(RRs - benchmarkestRRrho1)<=0])]
if (length(ind) > 0) {
 text(RRs[ind],powscont5[ind,1],benchmarklab,cex=1.3,col="blue") }

ind <- c(1:m)[(RRs - benchmarkestRRrho2) <= 0 & (RRs - benchmarkestRRrho2)==max((RRs - benchmarkestRRrho2)[(RRs - benchmarkestRRrho2)<=0])]
if (length(ind) > 0) {
 text(RRs[ind],powscont5[ind,2],benchmarklab,cex=1.3,col="orange") }

ind <- c(1:m)[(RRs - benchmarkestRRrho3) <= 0 & (RRs - benchmarkestRRrho3)==max((RRs - benchmarkestRRrho3)[(RRs - benchmarkestRRrho3)<=0])]
if (length(ind) > 0) {
 text(RRs[ind],powscont5[ind,3],benchmarklab,cex=1.3,col="green") }

ind <- c(1:m)[(RRs - benchmarkestRRrho4) <= 0 & (RRs - benchmarkestRRrho4)==max((RRs - benchmarkestRRrho4)[(RRs - benchmarkestRRrho4)<=0])]
if (length(ind) > 0) {
 text(RRs[ind],powscont5[ind,4],benchmarklab,cex=1.3,col="black") }

abline(h=alpha/2,lty=3)

text(RRs[round(m/3)],.95,paste("Fraction of subjects with VE=0: ",PlatVElowest),cex=1.45)

legend(x="topright",legend=c(paste("Power rho=",rhos[1],sep=""),paste("Power rho=",rhos[2],sep=""),paste("Power rho=",rhos[3],sep=""),paste("Power rho=",rhos[4],sep="")),
      lty=c(1,2,3,4),col=c("blue","orange","green","black"),lwd=2,cex=1.32)

title(paste("Power to Detect a Normally Distributed CoR in Vaccine Recipients [2-sided alpha = ",alpha,"]"))
mtext(paste("Overall VE = ",VEoverall,"; Number controls  = ",round(nPhase2*controlcaseratio),"; Number cases = ",round(nPhase2),"; Controls:cases = ",
controlcaseratio,":1"),side=1,line=2,outer=T,cex=1.3)
dev.off()

}

